# BigQuery Integration

Provides a service for executing queries on BigQuery, enabling seamless integration between Drupal and 
Google Cloud's data warehouse. It provides a base for interacting with BigQuery, allowing for future feature expansion.

Key Features:

* A Drupal service for executing queries on BigQuery.
* Configuration page to define the credentials file path.
* Secure handling of authentication using service account credentials.
* Extendable architecture to incorporate additional functionalities.
* Ideal for projects requiring efficient data retrieval and analysis from BigQuery within a Drupal environment.

## Requirements

* Composer (https://getcomposer.org/)
* A Google Cloud service account with a role according to your requirements:
  * https://developers.google.com/wallet/generic/getting-started/auth/rest#2_generate_a_google_cloud_service_account_key
  * https://cloud.google.com/iam/docs/understanding-roles#bigquery-roles
* Once you account is created, you can get your KEY as a JSON file with the credentials.

## Installation

Install as you would normally install a contributed Drupal module. For further information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-modules).

## Configuration

Put your JSON file in a no public folder. This file includes sensitive information, 
please do not push it to a public repository either.

Visit admin/config/services/bigquery-integration and type the location of your JSON file. Save the changes and click on
the tab 'Test connection'. If you see a message "Connection Successful", you are ready to use it.

## Usage

A new service 'bigquery_integration.service' is available to perform queries on BigQuery.
Example:

```
$bigquery = new \Drupal::service('bigquery_integration.service');
$bigquery->insertRow({dataset},{table},{array_values})
```

You can see the different methods inspecting the `src/Service/BigQueryIntegrationService.php` file



