<?php

namespace Drupal\bigquery_integration\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\bigquery_integration\Service\BigQueryIntegrationService;

/**
 * Class to perform some actions in BigQuery.
 */
class BigQueryIntegrationController extends ControllerBase {

  /**
   * Constructs for the class BigQueryIntegrationController.
   *
   * @param Drupal\bigquery_integration\Service\BigQueryIntegrationService $bigQueryService
   *   A BigQueryIntegrationService instance.
   */
  public function __construct(protected BigQueryIntegrationService $bigQueryService) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('bigquery_integration.service'));
  }

  /**
   * Simple method to test the connection with BigQuery.
   *
   * @return array
   *   The markup printed.
   */
  public function testConnection() {
    $big_query_client = $this->bigQueryService->getBigQueryClient();
    if (!$big_query_client) {
      return [
        '#markup' => t('Could not retrieve the BigQuery client, connection could not be established'),
      ];
    }

    try {
      // To verify the connection we only need to check if datasets method
      // does not throw an exception.
      iterator_to_array($big_query_client->datasets());
      return ['#markup' => 'Connection successful'];
    }
    catch (\Exception $e) {
      $this->getLogger('bigquery_integration')->error('Error @errnum: @errmsg', [
        '@errnum' => $e->getCode(),
        '@errmsg' => $e->getMessage(),
      ]);

      return [
        '#markup' => 'Error ' . $e->getCode() . ' executing the test. Please, see the log for more information',
      ];
    }
  }

}
