<?php

namespace Drupal\bigquery_integration\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Implements the settings form.
 *
 * @see \Drupal\Core\Form\ConfigFormBase
 */
class BigQueryIntegrationSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['bigquery_integration.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'bigquery_integration_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('bigquery_integration.settings');

    $form['json_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Path to the JSON file with the credentials.'),
      '#default_value' => $config->get('json_path') ?? FALSE,
      '#description' => $this->t('Specify the full path where the JSON credentials file is stored.
        It should not be accessible over the web. This can be changed in the settings.php file.<br/>
        You can create your service account to get your JSON file following this <a href=":link">link</a>', [
          ':link' => "https://developers.google.com/wallet/generic/getting-started/auth/rest#2_generate_a_google_cloud_service_account_key",
        ]
      ),
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('bigquery_integration.settings')
      ->set('json_path', $form_state->getValue('json_path'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
